/**
 * @file
 * Provides necessary realtime recalculations reacting on fields editing in line item manager widget.
 */

(function ($) {

  Drupal.behaviors.attach_line_items_profits_form_handlers = {
    attach: function (context, settings) {
      var currency_symbol = settings.currency_symbol;
      var item_manager = $('#line-item-manager');
      if (item_manager.length === 0) {
        return;
      }

      var price_control_inputs = item_manager.find('.field-widget-commerce-price-full input, input.field-widget-field-cost, .form-item input[name$="[quantity]"]', context);
      price_control_inputs.on('keyup', {
        currency_symbol: settings.currency_symbol
      }, processPriceValueChanges);
      price_control_inputs.on('keyup', {
        currency_symbol: settings.currency_symbol,
        context: context,
        recalculation_warning: settings.recalculation_warning,
      }, function (event) {
        calculateOrderTotal(event.data.currency_symbol, event.data.context, event.data.recalculation_warning);
      });

      // Don't want recalculation to happen on initial page loading
      if ($(context).attr('id') !== undefined) {
        calculateOrderTotal(currency_symbol, context, settings.recalculation_warning);
      }
    }
  };

  function processPriceValueChanges(event) {
    var textfield = $(this);
    var trimmed_value = textfield.val().replace(' ', '');
    if (trimmed_value !== textfield.val()) {
      textfield.val(trimmed_value);
    }

    var row = textfield.parents('#line-item-manager tr');

    var price = row.find('td:nth-child(7) input').val();
    var quantity = row.find('td:nth-child(8) input').val();

    var cost = 0;
    if (row.find('input.field-widget-field-cost').length > 0) {
      cost = row.find('input.field-widget-field-cost').val();
    } else {
      var cost_string = row.children('td:nth-child(4)').html();
      cost = cost_string ? cost_string.replace(/[^0-9]/g, '') : 0;
    }
    var margin = cost > 0 ? Math.round(100 * (price - cost) / cost) : '';
    row.children('td:nth-child(5)').text(margin);
    setFormattedPriceText(row.children('td:nth-child(6)'), price - cost, event.data.currency_symbol);
    setFormattedPriceText(row.children('td:nth-child(9)'), price * quantity, event.data.currency_symbol);
  }

  function calculateOrderTotal(currency_symbol, context, message) {
    var total = 0;
    $('#line-item-manager tbody tr', context).each(function () {
      var row = $(this);
      var quantity = row.find('.form-item input[name$="[quantity]"]').val();
      var price = row.find('.field-widget-commerce-price-full input').val();
      if (quantity !== undefined && price !== undefined) {
        total += price * quantity;
      }
    });
    setFormattedPriceText($('#order-edit-order-total .value', context), total, currency_symbol);
    if (message !== "") {
      $('#order-edit-order-total .recalculation-warning').text(message);
    }
  }

  function setFormattedPriceText(item, price, currency_symbol) {
    item.text(currency_symbol.before + Math.round(price) + ' ' + currency_symbol.after);
  }

})(jQuery);
